@@ -21,11 +21,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <syslog.h>
 #include <vpn.h>
 #include "pam.h"
 #include <sec-mod-acct.h>
 
+#include "log.h"
+
 #ifdef HAVE_PAM
 
 #include <security/pam_appl.h>
@@ -50,7 +51,7 @@ pam_handle_t *ph;
 struct pam_conv dc;
 
 	if (ai->username[0] == 0) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "PAM-acct: no username present");
 		return ERR_AUTH_FAIL;
 	}
@@ -59,13 +60,13 @@ struct pam_conv dc;
 	dc.appdata_ptr = NULL;
 	pret = pam_start(PACKAGE, ai->username, &dc, &ph);
 	if (pret != PAM_SUCCESS) {
-		syslog(LOG_NOTICE, "PAM-acct init: %s", pam_strerror(ph, pret));
+		oc_syslog(LOG_NOTICE, "PAM-acct init: %s", pam_strerror(ph, pret));
 		goto fail1;
 	}
 
 	pret = pam_acct_mgmt(ph, PAM_DISALLOW_NULL_AUTHTOK);
 	if (pret != PAM_SUCCESS) {
-		syslog(LOG_INFO, "PAM-acct account error: %s", pam_strerror(ph, pret));
+		oc_syslog(LOG_INFO, "PAM-acct account error: %s", pam_strerror(ph, pret));
 		goto fail2;
 	}
 
