@@ -20,7 +20,6 @@
 #include <config.h>
 #include <auth/common.h>
 
-const char* pass_msg_second = "Please enter your challenge password.";
-const char* pass_msg_failed = "Login failed.\nPlease enter your password.";
-const char* pass_msg_otp = "Please enter your OTP password.";
-
+const char pass_msg_second[] = "Please enter your challenge password.";
+const char pass_msg_failed[] = "Login failed.\nPlease enter your password.";
+const char pass_msg_otp[] = "Please enter your OTP password.";
