@@ -18,7 +18,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <syslog.h>
 #include <unistd.h>
 #include <vpn.h>
 #include <ctype.h>
@@ -32,6 +31,8 @@
 #include <cjose/cjose.h>
 #include <time.h>
 
+#include "log.h"
+
 #define MINIMUM_KEY_REFRESH_INTERVAL (900)
 
 typedef struct oidc_vctx_st {
@@ -61,7 +62,7 @@ static void oidc_vhost_init(void **vctx, void *pool, void *additional)
 
 	vc = talloc(pool, struct oidc_vctx_st);
 	if (vc == NULL) {
-		syslog(LOG_ERR, "ocserv-oidc allocation failure!\n");
+		oc_syslog(LOG_ERR, "ocserv-oidc allocation failure!\n");
 		exit(EXIT_FAILURE);
 	}
 	vc->config = NULL;
@@ -69,30 +70,30 @@ static void oidc_vhost_init(void **vctx, void *pool, void *additional)
 	vc->pool = pool;
 
 	if (config == NULL) {
-		syslog(LOG_ERR, "ocserv-oidc: no configuration passed!\n");
+		oc_syslog(LOG_ERR, "ocserv-oidc: no configuration passed!\n");
 		exit(EXIT_FAILURE);
 	}
 
 	vc->config = json_load_file(config, 0, &err);
 	if (vc->config == NULL) {
-		syslog(LOG_ERR, "ocserv-oidc: failed to load config file: %s\n", config);
+		oc_syslog(LOG_ERR, "ocserv-oidc: failed to load config file: %s\n", config);
 		exit(EXIT_FAILURE);
 	}
 
 	if (!json_object_get(vc->config, "openid_configuration_url")) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: config file missing openid_configuration_url\n");
 		exit(EXIT_FAILURE);
 	}
 
 	if (!json_object_get(vc->config, "required_claims")) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: config file missing required_claims\n");
 		exit(EXIT_FAILURE);
 	}
 
 	if (!json_object_get(vc->config, "user_name_claim")) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: config file missing user_name_claim\n");
 		exit(EXIT_FAILURE);
 	}
@@ -104,7 +105,7 @@ static void oidc_vhost_init(void **vctx, void *pool, void *additional)
 	}
 
 	if (!oidc_fetch_oidc_keys(vc)) {
-		syslog(LOG_ERR, "ocserv-oidc: failed to load jwks\n");
+		oc_syslog(LOG_ERR, "ocserv-oidc: failed to load jwks\n");
 		exit(EXIT_FAILURE);
 	}
 
@@ -249,7 +250,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 
 	curl = curl_easy_init();
 	if (!curl) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to download JSON document: URI %s\n",
 		       uri);
 		goto cleanup;
@@ -257,7 +258,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 
 	res = curl_easy_setopt(curl, CURLOPT_URL, uri);
 	if (res != CURLE_OK) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to download JSON document: URI %s, CURLcode %d\n",
 		       uri, res);
 		goto cleanup;
@@ -267,7 +268,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 	    curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION,
 			     oidc_json_parser_context_callback);
 	if (res != CURLE_OK) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to download JSON document: URI %s, CURLcode %d\n",
 		       uri, res);
 		goto cleanup;
@@ -275,7 +276,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 
 	res = curl_easy_setopt(curl, CURLOPT_WRITEDATA, &context);
 	if (res != CURLE_OK) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to download JSON document: URI %s, CURLcode %d\n",
 		       uri, res);
 		goto cleanup;
@@ -283,7 +284,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 
 	res = curl_easy_perform(curl);
 	if (res != CURLE_OK) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to download JSON document: URI %s, CURLcode %d\n",
 		       uri, res);
 		goto cleanup;
@@ -291,7 +292,7 @@ static json_t *oidc_fetch_json_from_uri(void * pool, const char *uri)
 
 	json = json_loadb(context.buffer, context.offset, 0, &err);
 	if (!json) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to parse JSON document: URI %s\n",
 		       uri);
 		goto cleanup;
@@ -323,7 +324,7 @@ static bool oidc_fetch_oidc_keys(oidc_vctx_st * vctx)
 	json_t *value;
 
 	if (!openid_configuration_url) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: openid_configuration_url missing from config\n");
 		goto cleanup;
 	}
@@ -334,21 +335,21 @@ static bool oidc_fetch_oidc_keys(oidc_vctx_st * vctx)
 				       (openid_configuration_url));
 
 	if (!oidc_config) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: Unable to fetch config doc from %s\n", json_string_value(openid_configuration_url));
 		goto cleanup;
 	}
 
 	json_t *jwks_uri = json_object_get(oidc_config, "jwks_uri");
 	if (!jwks_uri || !json_string_value(jwks_uri)) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: jwks_uri missing from config doc\n");
 		goto cleanup;
 	}
 
 	jwks = oidc_fetch_json_from_uri(vctx->pool, json_string_value(jwks_uri));
 	if (!jwks) {
-		syslog(LOG_ERR,
+		oc_syslog(LOG_ERR,
 		       "ocserv-oidc: failed to fetch keys from jwks_uri %s\n",
 		       json_string_value(jwks_uri));
 		goto cleanup;
@@ -356,14 +357,14 @@ static bool oidc_fetch_oidc_keys(oidc_vctx_st * vctx)
 
 	array = json_object_get(jwks, "keys");
 	if (array == NULL) {
-		syslog(LOG_ERR, "ocserv-oidc: JWK keys malformed\n");
+		oc_syslog(LOG_ERR, "ocserv-oidc: JWK keys malformed\n");
 		goto cleanup;
 	}
 
 	// Log the keys obtained
 	json_array_foreach(array, index, value) {
 		json_t *key_kid = json_object_get(value, "kid");
-		syslog(LOG_INFO,
+		oc_syslog(LOG_INFO,
 		       "ocserv-oidc: fetched new JWK %s\n",
 			   json_string_value(key_kid)
 		       );
@@ -401,24 +402,24 @@ static bool oidc_verify_lifetime(json_t * token_claims)
 	time_t current_time = time(NULL);
 
 	if (!token_nbf || !json_integer_value(token_nbf)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'nbf' claim\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'nbf' claim\n");
 		goto cleanup;
 	}
 
 	if (!token_exp || !json_integer_value(token_exp)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'exp' claim\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'exp' claim\n");
 		goto cleanup;
 	}
 
 	if (!token_iat || !json_integer_value(token_iat)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'iat' claim\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token missing 'iat' claim\n");
 		goto cleanup;
 	}
 
 	// Check to ensure the token is within it's validity
 	if (json_integer_value(token_nbf) > current_time
 	    || json_integer_value(token_exp) < current_time) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Token not within validity period NBF: %lld EXP: %lld Current: %ld\n",
 		       json_integer_value(token_nbf),
 		       json_integer_value(token_exp), current_time);
@@ -446,7 +447,7 @@ static bool oidc_verify_required_claims(json_t * required_claims,
 		token_claim_value =
 		    json_object_get(token_claims, required_claim_name);
 		if (!json_equal(required_claim_value, token_claim_value)) {
-			syslog(LOG_NOTICE,
+			oc_syslog(LOG_NOTICE,
 			       "ocserv-oidc: Required claim not met. Claim: %s Expected Value: %s\n",
 			       required_claim_name,
 			       json_string_value(required_claim_value));
@@ -470,7 +471,7 @@ static bool oidc_map_user_name(json_t * user_name_claim,
 	json_t *token_user_name_claim =
 	    json_object_get(token_claims, json_string_value(user_name_claim));
 	if (!token_user_name_claim || !json_string_value(token_user_name_claim)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token missing '%s' claim\n",
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token missing '%s' claim\n",
 		       json_string_value(user_name_claim));
 		goto cleanup;
 	}
@@ -493,7 +494,7 @@ static json_t *oidc_extract_claims(cjose_jws_t * jws)
 
 	// Extract the claim portion from the token
 	if (!cjose_jws_get_plaintext(jws, &plain_text, &plain_text_size, &err)) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Failed to get plain text from token\n");
 		goto cleanup;
 	}
@@ -502,7 +503,7 @@ static json_t *oidc_extract_claims(cjose_jws_t * jws)
 	token_claims =
 	    json_loadb((char *)plain_text, plain_text_size, 0, &json_err);
 	if (!token_claims) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Failed to get claims from token\n");
 		goto cleanup;
 	}
@@ -525,20 +526,20 @@ static bool oidc_verify_signature(oidc_vctx_st * vctx, cjose_jws_t * jws)
 	json_t *value;
 
 	if (vctx->jwks == NULL) {
-		syslog(LOG_NOTICE, "ocserv-oidc: JWK keys not available\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: JWK keys not available\n");
 		goto cleanup;
 	}
 
 	array = json_object_get(vctx->jwks, "keys");
 	if (array == NULL) {
-		syslog(LOG_NOTICE, "ocserv-oidc: JWK keys malformed\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: JWK keys malformed\n");
 		goto cleanup;
 	}
 
 	// Get the token header
 	token_header = cjose_jws_get_protected(jws);
 	if (token_header == NULL) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Token malformed - no header\n");
 		goto cleanup;
 	}
@@ -546,13 +547,13 @@ static bool oidc_verify_signature(oidc_vctx_st * vctx, cjose_jws_t * jws)
 	// Get the kid of the key used to sign this token
 	token_kid = json_object_get(token_header, "kid");
 	if (token_kid == NULL || !json_string_value(token_kid)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - no kid\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - no kid\n");
 		goto cleanup;
 	}
 
 	token_typ = json_object_get(token_header, "typ");
 	if (token_typ == NULL || !json_string_value(token_typ) || strcmp(json_string_value(token_typ), "JWT")) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - wrong typ claim\n");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - wrong typ claim\n");
 		goto cleanup;
 	}
 
@@ -567,16 +568,16 @@ static bool oidc_verify_signature(oidc_vctx_st * vctx, cjose_jws_t * jws)
 
 	if (jwk == NULL) {
 		time_t now;
-		syslog(LOG_NOTICE, "ocserv-oidc: JWK with kid=%s not found\n",
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: JWK with kid=%s not found\n",
 		       json_string_value(token_kid));
 
-		syslog(LOG_NOTICE, "ocserv-oidc: attempting to download new JWKs");
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: attempting to download new JWKs");
 		now = time(NULL);
 		if ((now - vctx->last_jwks_load_time) > vctx->minimum_jwk_refresh_time) {
 			oidc_fetch_oidc_keys(vctx);
 		}
 		else {
-			syslog(LOG_NOTICE, "ocserv-oidc: skipping JWK refresh");
+			oc_syslog(LOG_NOTICE, "ocserv-oidc: skipping JWK refresh");
 		}
 
 		// Fail the request and let the client try again.
@@ -584,7 +585,7 @@ static bool oidc_verify_signature(oidc_vctx_st * vctx, cjose_jws_t * jws)
 	}
 
 	if (!cjose_jws_verify(jws, jwk, &err)) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token failed validation %s\n",
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token failed validation %s\n",
 		       err.message);
 		goto cleanup;
 	}
@@ -611,33 +612,33 @@ static bool oidc_verify_token(oidc_vctx_st * vctx, const char *token,
 
 	jws = cjose_jws_import(token, token_length, &err);
 	if (jws == NULL) {
-		syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - %s\n",
+		oc_syslog(LOG_NOTICE, "ocserv-oidc: Token malformed - %s\n",
 		       err.message);
 		goto cleanup;
 	}
 
 	if (!oidc_verify_signature(vctx, jws)) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Token signature validation failed\n");
 		goto cleanup;
 	}
 
 	token_claims = oidc_extract_claims(jws);
 	if (!token_claims) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Unable to access token claims\n");
 		goto cleanup;
 	}
 
 	if (!oidc_verify_lifetime(token_claims)) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Token lifetime validation failed\n");
 		goto cleanup;
 	}
 
 	if (!oidc_verify_required_claims
 	    (json_object_get(vctx->config, "required_claims"), token_claims)) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Token required claims validation failed\n");
 		goto cleanup;
 	}
@@ -645,7 +646,7 @@ static bool oidc_verify_token(oidc_vctx_st * vctx, const char *token,
 	if (!oidc_map_user_name
 	    (json_object_get(vctx->config, "user_name_claim"), token_claims,
 	     user_name)) {
-		syslog(LOG_NOTICE,
+		oc_syslog(LOG_NOTICE,
 		       "ocserv-oidc: Unable to map user name claim\n");
 		goto cleanup;
 	}
