@@ -18,8 +18,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  */
-#ifndef IP_LEASE_H
-# define IP_LEASE_H
+#ifndef OC_IP_LEASE_H
+# define OC_IP_LEASE_H
 
 #include <vpn.h>
 #include <string.h>
