@@ -19,15 +19,8 @@
 #ifndef OC_ISOLATE_H
 # define OC_ISOLATE_H
 
+void set_worker_fd_limits(struct worker_st *);
 
-void init_fd_limits_default(struct main_server_st * s);
-
-/* Adjusts the file descriptor limits for the main or worker processes
- */
-void update_fd_limits(struct main_server_st * s, unsigned main);
-
-void set_self_oom_score_adj(struct main_server_st * s);
-
-void drop_privileges(struct main_server_st * s);
+void drop_privileges(struct worker_st *ws, main_server_st *s);
 
 #endif
