@@ -15,8 +15,8 @@
  * Lesser General Public License for more details.
  */
 
-#ifndef LZS_H
-# define LZS_H
+#ifndef OC_LZS_H
+# define OC_LZS_H
 
 int lzs_decompress(unsigned char *dst, int dstlen, const unsigned char *src, int srclen);
 int lzs_compress(unsigned char *dst, int dstlen, const unsigned char *src, int srclen);
