@@ -24,8 +24,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <occtl/occtl.h>
-#include <c-strcase.h>
-#include <minmax.h>
 #include <common.h>
 
 typedef struct ip_entries_st {
@@ -57,8 +55,6 @@ void ip_entries_add(void *pool, const char* ip, unsigned ip_size)
 	strlcpy(ip_entries[ip_entries_size].ip, ip, sizeof(ip_entries[ip_entries_size].ip));
 	ip_entries[ip_entries_size].ip_size = ip_size;
 	ip_entries_size++;
-
-	return;
 }
 
 char* search_for_ip(unsigned idx, const char* match, int match_size)
@@ -70,7 +66,7 @@ unsigned i;
 
 	for (i=idx;i<ip_entries_size;i++) {
 		if (match_size <= ip_entries[i].ip_size) {
-			if (c_strncasecmp(match, ip_entries[i].ip, match_size) == 0)
+			if (strncasecmp(match, ip_entries[i].ip, match_size) == 0)
 				return strdup(ip_entries[i].ip);
 		}
 	}
