@@ -1157,15 +1157,15 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 			char buf2[32];
 
 			if (args->user[i]->rx_per_sec > 0 && args->user[i]->tx_per_sec > 0) {
-				bytes2human(args->user[i]->rx_per_sec, buf1, sizeof(buf1), "/sec");
-				bytes2human(args->user[i]->tx_per_sec, buf2, sizeof(buf2), "/sec");
+				bytes2human(args->user[i]->rx_per_sec, buf1, sizeof(buf1), "/s");
+				bytes2human(args->user[i]->tx_per_sec, buf2, sizeof(buf2), "/s");
 
 				print_pair_value(out, params, "Limit RX", buf1, "Limit TX", buf2, 1);
 			} else if (args->user[i]->tx_per_sec > 0) {
-				bytes2human(args->user[i]->tx_per_sec, buf1, sizeof(buf1), "/sec");
+				bytes2human(args->user[i]->tx_per_sec, buf1, sizeof(buf1), "/s");
 				print_single_value(out, params, "Limit TX", buf1, 1);
 			} else if (args->user[i]->rx_per_sec > 0) {
-				bytes2human(args->user[i]->rx_per_sec, buf1, sizeof(buf1), "/sec");
+				bytes2human(args->user[i]->rx_per_sec, buf1, sizeof(buf1), "/s");
 				print_single_value(out, params, "Limit RX", buf1, 1);
 			}
 		}
@@ -1180,6 +1180,7 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 		print_single_value_ex(out, params, "Connected at", str_since, tmpbuf, 1);
 
 		if (HAVE_JSON(params)) {
+			print_single_value_int(out, params, "raw_connected_at", t, 1);
 			print_single_value(out, params, "Full session", shorten(args->user[i]->safe_id.data, args->user[i]->safe_id.len, 0), 1);
 #ifdef OCSERV_0_11_6_COMPAT
 			/* compat with previous versions */
