@@ -18,8 +18,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  */
-#ifndef SETPROCTITLE_H
-# define SETPROCTITLE_H
+#ifndef OC_SETPROCTITLE_H
+# define OC_SETPROCTITLE_H
 
 # include <config.h>
 
