@@ -23,7 +23,7 @@
 
 #include <config.h>
 #include <gnutls/gnutls.h>
-#include <http_parser.h>
+#include <llhttp.h>
 #include <ccan/htable/htable.h>
 #include <ccan/list/list.h>
 #include <sys/types.h>
@@ -251,6 +251,8 @@ struct cfg_st {
 
 	char **friendly_group_list; /* the same size as group_list_size */
 
+	unsigned select_group_by_url;
+	unsigned auto_select_group;
 	char *default_select_group;
 
 	char **custom_header;
