@@ -155,13 +155,16 @@ int main(int argc, char **argv)
 	snapshot_terminate(config_snapshot);
 	config_snapshot = NULL;
 
-	flags = LOG_PID | LOG_NDELAY;
+	if (GETPCONFIG(s)->syslog) {
+		flags = LOG_PID | LOG_NDELAY;
 #ifdef LOG_PERROR
-	if (GETPCONFIG(s)->debug != 0)
-		flags |= LOG_PERROR;
+		if (GETPCONFIG(s)->log_stderr)
+			flags |= LOG_PERROR;
 #endif
-	openlog("ocserv", flags, LOG_DAEMON);
-	syslog_open = 1;
+		openlog("ocserv", flags, LOG_DAEMON);
+		syslog_open = 1;
+	}
+
 #ifdef HAVE_LIBWRAP
 	allow_severity = LOG_DAEMON | LOG_INFO;
 	deny_severity = LOG_DAEMON | LOG_WARNING;
@@ -171,16 +174,13 @@ int main(int argc, char **argv)
 	/* Initialize kkdcp structures */
 	ret = asn1_array2tree(kkdcp_asn1_tab, &_kkdcp_pkix1_asn, NULL);
 	if (ret != ASN1_SUCCESS) {
-		mslog(s, NULL, LOG_ERR, "KKDCP ASN.1 initialization error");
+		oc_syslog(LOG_ERR, "KKDCP ASN.1 initialization error");
 		exit(EXIT_FAILURE);
 	}
 #endif
-
-	init_fd_limits_default(s);
-
 	sigprocmask(SIG_SETMASK, &sig_default_set, NULL);
 
-	setproctitle(PACKAGE_NAME "-worker");
+	setproctitle(PACKAGE "-worker");
 	kill_on_parent_kill(SIGTERM);
 
 	ws->main_pool = s->main_pool;
@@ -190,8 +190,10 @@ int main(int argc, char **argv)
 	DTLS_ACTIVE(ws)->dtls_tptr.fd = -1;
 	DTLS_INACTIVE(ws)->dtls_tptr.fd = -1;
 
+	set_worker_fd_limits(ws);
+
 	/* Drop privileges after this point */
-	drop_privileges(s);
+	drop_privileges(ws, s);
 
 	vpn_server(ws);
 
